# Hedonics

**Human Hedonics Teleology Classification System** — the classification framework behind Hedonics Driven Development (HDD).

Classify software by the human purposes it serves, not the technology it uses.

Part of the [High Noon](https://github.com/altpath-ai/highnoon) project by [AltPath AI](https://altpath.ai).

## Status

Pre-alpha. Under active development.

## License

MIT
